#ifndef FORMHOME_H
#define FORMHOME_H

#include <QWidget>
#include <QString>
#include <QSqlQueryModel>
#include "formtasklistnavigator.h"


namespace Ui {
class FormHome;
}

class FormHome : public QWidget
{
    Q_OBJECT
    
public:
    explicit FormHome(QWidget *parent = 0);
    ~FormHome();

public slots:

    
private slots:
    void on_listWidgetHome_activated(const QModelIndex &index);

    void on_listViewGroups_activated(const QModelIndex &index);

    void on_pushButton_2_clicked();

    void on_pushButton_clicked();

    void updateQueries();

private:
    Ui::FormHome *ui;
    QSqlQueryModel *group_model;
    QSqlQueryModel *view_model;

    FormTaskListNavigator* nav;

    void launchInbox();
    void launchToday();
    void launchLate();
    void launchTomorrow();
    void launchTasks();
    void launchNotes();
    void getNav();

};

#endif // FORMHOME_H
